class CCP : 
    def __init__(self,ccp : str) : 
        self.ccp = ccp
    def get_cle(self) :
        # Return the cle of the account
        x = self.ccp.zfill(10)
        values = list(x)
        cc = 0
        z = 9
        for i in range(4, 14):
            cc += int(values[z]) * i
            z -= 1
        ccc = str(cc % 100).zfill(2)
        return ccc
    def get_rip(self,only_cle=None) : 
        # Return the rip of the account including the first 8 digits 00799999
        self.ccp = int(self.ccp)
        if ((self.ccp * 100) % 97) + 85 > 97:
            x = 97 - (((self.ccp * 100) % 97) + 85 - 97)
            if x < 10:
                return "00799999"+ str(self.ccp).zfill(10) + str(x) if not(only_cle) else str(x)
            else:
                return "00799999"+ str(self.ccp).zfill(10) + str(x) if not(only_cle) else str(x)
        else:
            y = 97 - (((self.ccp * 100) % 97) + 85)
            if y < 10:
                return "00799999"+ str(self.ccp).zfill(10) + str(y) if not(only_cle) else str(y)
            else:
                return "00799999"+ str(self.ccp).zfill(10) + str(y)if not(only_cle) else str(y)
    def get_rip_cle(self) : 
        # Return only the cle of the rip 
        return self.get_rip(only_cle=True)


from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="algeria",
    version="0.1.0",
    author="Mohammed BADI",
    author_email="badi.mohammed@univ-oran2.dz",
    description="Python library which gives you a (clé) and (rip) of a given (ccp) CCP number account, additional features may be added to the library in the future",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mouh2020/algeria",
    packages=["algeria"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    python_requires=">=3.6",
)
